@@ -19,7 +19,7 @@ dbQuoteLiteral_DBIConnection <- function(conn, x, ...) {
   if (inherits(x, "POSIXt")) {
     return(dbQuoteString(
       conn,
-      strftime(as.POSIXct(x), "%Y-%m-%d %H-%M-%S%z")
+      strftime(as.POSIXct(x), "%Y-%m-%d %H:%M:%S%z")
     ))
   }
 
@@ -48,14 +48,8 @@ dbQuoteLiteral_DBIConnection <- function(conn, x, ...) {
     return(SQL(blob_data, names = names(x)))
   }
 
-  if (is.double(x)) {
-    out <- sprintf("%.17e", x)
-    out[is.na(x)] <- "NULL"
-    return(SQL(out, names = names(x)))
-  }
-
   if (is.logical(x)) {
-    x <- as.integer(x)
+    x <- as.numeric(x)
   }
 
   x <- as.character(x)
